#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-logger
version:              0.3.36
visibility:           public
id:                   monad-logger-0.3.36-7Ivl5kcncUr1znklCaMQsw
key:                  monad-logger-0.3.36-7Ivl5kcncUr1znklCaMQsw
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/monad-logger#readme
synopsis:             A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>

category:             System
abi:                  705c43c75eb7cd71c2ac53a87d31a768
exposed:              True
exposed-modules:      Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules:       Paths_monad_logger
import-dirs:          /usr/lib/ghc-8.10.2/site-local/monad-logger-0.3.36
library-dirs:         /usr/lib/ghc-8.10.2/site-local/monad-logger-0.3.36
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/monad-logger-0.3.36
hs-libraries:         HSmonad-logger-0.3.36-7Ivl5kcncUr1znklCaMQsw
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    conduit-1.3.4-LKkovHkWTkK2IXYqvxsWMR
    conduit-extra-1.3.5-77XQGvT8hG4J3W5as0TsnC exceptions-0.10.4
    fast-logger-3.0.2-4brp8rjZ8ZTJd0WKKbI6MC
    lifted-base-0.2.3.12-5daBF3LNBSuEjCWowlSZ0U
    monad-control-1.0.2.3-D0QtFvOGiobG7KTK5Cfhxz
    monad-loops-0.4.3-C0LVokhtCoUF1FVS5cJB0Q mtl-2.2.2
    resourcet-1.2.4.2-E1PquPTZKgvLbHxPSs1hvZ stm-2.5.0.0
    stm-chans-3.0.0.4-IkLPF4Ira3LYY9IzoULtB template-haskell-2.16.0.0
    text-1.2.3.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-5NQt00osHIwIugRpgg1tUI
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM
    unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV

haddock-interfaces:
    /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock

haddock-html:         /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

